//
//  MadvertiseCustomEventBanner.m
//  DFPAdapter
//
//  Created by MacBook Pro on 02/10/2019.
//  Copyright © 2019 MacBook Pro. All rights reserved.
//

#import "MadvertiseCustomEventBanner.h"
#import "MNGAdsSDKFactory.h"

@import GoogleMobileAds;

@interface MadvertiseCustomEventBanner () <GADCustomEventBanner,MNGAdsAdapterBannerDelegate,MNGClickDelegate>
@property(nonatomic, strong)  MNGAdsSDKFactory * bannerFactory;
@end

@implementation MadvertiseCustomEventBanner{
   
}
@synthesize delegate;

UIViewController* _viewController;

-(id)init {
    self = [super init];
    return self;
}
-(void)setViewController:(UIViewController*)viewController{
    _viewController = viewController;
}

- (void)requestBannerAd:(GADAdSize)adSize
              parameter:(NSString *)serverParameter
                  label:(NSString *)serverLabel
                request:(GADCustomEventRequest *)request {
    
    // Create the bannerView with the appropriate size.
    
    if (_bannerFactory.isBusy) {
        NSLog(@"[MAdvertise]: Ads Factory is busy");
        return;
    }
  
    NSLog(@"[MAdvertise]: request BannerAd from Custom Class called");
    
    NSString *appID = [self getAppIdByPlacementFromServerParameter:serverParameter];
    [MNGAdsSDKFactory initWithAppId:appID];
    _bannerFactory = [[MNGAdsSDKFactory alloc]init];
    _bannerFactory.bannerDelegate = self;
    _bannerFactory.viewController = _viewController;
    _bannerFactory.placementId = serverParameter;
    _bannerFactory.clickDelegate = self;
    MNGPreference *preferences = [[MNGPreference alloc]init];
    CLLocation *locationRequest = [[CLLocation alloc] initWithLatitude:request.userLatitude longitude:request.userLongitude];
    preferences.location = locationRequest;
    preferences.keyWord = [self createMngPreferenceKeyWord:request];
    MNGAdSize size  = [self getSize:adSize ];
    [_bannerFactory loadBannerInFrame:size withPreferences:preferences];
}

- (NSString * )getAppIdByPlacementFromServerParameter:(NSString  *)serverParameter {
    NSString * appID;
    if (serverParameter != nil) {
        NSArray *items = [serverParameter componentsSeparatedByString:@"/"];
        if (items.count >= 2) {
            appID  =[items objectAtIndex:1];
        }
    }
    return appID;
}
-(NSString*)createMngPreferenceKeyWord:(GADCustomEventRequest *)request{
    NSString* keyWord = @"";
    NSString* userRequest = @"";
    NSString*  requestExtrasString = @"";
    if (request.userKeywords.count == 1) {
        userRequest = [request.userKeywords[0] stringByAppendingString:@";"];
    }
    if (request.additionalParameters != nil) {
        requestExtrasString = [NSString stringWithFormat:@"%@", request.additionalParameters];
        requestExtrasString = [requestExtrasString stringByReplacingOccurrencesOfString:@"{"withString:@""];
        requestExtrasString = [requestExtrasString stringByReplacingOccurrencesOfString:@"}"withString:@""];
        requestExtrasString = [requestExtrasString stringByReplacingOccurrencesOfString:@"\n"withString:@""];
        requestExtrasString = [requestExtrasString stringByReplacingOccurrencesOfString:@" "withString:@""];
        NSString *lastChar = [requestExtrasString substringFromIndex:[requestExtrasString length] - 1];
        if ([lastChar isEqualToString:@";"]){
            requestExtrasString = [requestExtrasString substringToIndex:[requestExtrasString length] - 1];
        }
    }
    keyWord = [userRequest stringByAppendingString:requestExtrasString];
    return keyWord;
}
-(void)adsAdapter:(MNGAdsAdapter *)adsAdapter bannerDidLoad:(UIView *)adView preferredHeight:(CGFloat)preferredHeight {
    NSLog(@"[MAdvertise]: adsAdapter  bannerDidLoad");
    
    [delegate customEventBanner:self didReceiveAd:adView];
    
    
}
-(void)adsAdapter:(MNGAdsAdapter *)adsAdapter bannerDidFailWithError:(NSError *)error{
    NSLog(@"[MAdvertise]: adsAdapter bannerDidFailWithError");
    
    [delegate customEventBanner:self didFailAd:error];
    
}
-(void)adsAdapterAdWasClicked:(MNGAdsAdapter *)adsAdapter{
    [delegate customEventBannerWasClicked:self];
    [self.delegate customEventBannerWillLeaveApplication:self];
}

- (MNGAdSize)getSize:(GADAdSize)adSize {
    
    MNGAdSize size ;
    if (GADAdSizeEqualToSize(adSize,kGADAdSizeBanner)) {
        BOOL isIPAD = ([[UIDevice currentDevice] userInterfaceIdiom] == UIUserInterfaceIdiomPad);
        if (isIPAD) {
            size = kMNGAdSizeLeaderboard;
        } else {
            size = kMNGAdSizeBanner;
        }
        size = kMNGAdSizeBanner;
    } else if (GADAdSizeEqualToSize(adSize,kGADAdSizeLargeBanner)) {
        size = kMNGAdSizeLargeBanner;
    }else {
        if (GADAdSizeEqualToSize(adSize,kGADAdSizeMediumRectangle)) {
            size = kMNGAdSizeMediumRectangle;
        } else {
            if (GADAdSizeEqualToSize(adSize,kGADAdSizeFullBanner)) {
                size = kMNGAdSizeFullBanner;
            }  else {
                if (GADAdSizeEqualToSize(adSize,kGADAdSizeLeaderboard)) {
                    size = kMNGAdSizeLeaderboard;
                }  else {
                    BOOL isIPAD = ([[UIDevice currentDevice] userInterfaceIdiom] == UIUserInterfaceIdiomPad);
                    size = (isIPAD)?kMNGAdSizeDynamicLeaderboard:kMNGAdSizeDynamicBanner;
                }
            }
        }
    }
    return size;
}

-(void)dealloc{
    if (_bannerFactory != nil) {
        _bannerFactory = nil;
    }
}

@end
