//
//  MadvertiseCustomEventInterstitial.m
//  DFPAdapter
//
//  Created by MacBook Pro on 02/10/2019.
//  Copyright © 2019 MacBook Pro. All rights reserved.
//

#import "MadvertiseCustomEventInterstitial.h"
#import "MNGAdsSDKFactory.h"

@interface MadvertiseCustomEventInterstitial () <MNGAdsAdapterInterstitialDelegate,MNGClickDelegate>
@property(nonatomic, strong)  MNGAdsSDKFactory * _interFactory;
@end


@implementation MadvertiseCustomEventInterstitial {
}

@synthesize delegate;


UIViewController* _viewController;

-(id)init {
    self = [super init];
    return self;
}
/**
 viewController that th ad will be shown
@warning required in interstitial
*/
-(void)setViewController:(UIViewController*)viewController{
    _viewController = viewController;
}


/**
Called by mediation when your custom event is scheduled to be executed.
 */
- (void)requestInterstitialAdWithParameter:(NSString *)serverParameter
                                     label:(NSString *)serverLabel
                                   request:(GADCustomEventRequest *)request {
    if (self._interFactory.isBusy) {
        NSLog(@"[MAdvertise]:Ads Factory is busy");
        return;
    }
    NSString *appID = [self getAppIdByPlacementFromServerParameter:serverParameter];
    [MNGAdsSDKFactory initWithAppId:appID];
    self._interFactory = [[MNGAdsSDKFactory alloc]init];
    self._interFactory.interstitialDelegate = self;
    self._interFactory.placementId =  serverParameter ; //serverParameter ;
    self._interFactory.viewController = _viewController;
    self._interFactory.clickDelegate = self;
    MNGPreference *preferences = [[MNGPreference alloc]init];
    preferences.keyWord = [self createMngPreferenceKeyWord:request];
    CLLocation *locationRequest = [[CLLocation alloc] initWithLatitude:request.userLatitude longitude:request.userLongitude];
    preferences.location = locationRequest;
    [self._interFactory loadInterstitialWithPreferences:preferences autoDisplayed:NO];
    
}

-(void)presentFromRootViewController:(UIViewController *)rootViewController{
    if (self._interFactory != nil) {
          self._interFactory.viewController = rootViewController;
          if([self._interFactory displayInterstitial]) {
              if ([self.delegate respondsToSelector: @selector(customEventInterstitialWillPresent:)]) {
                  [self.delegate customEventInterstitialWillPresent:self];
              }
          }
      }
}

#pragma mark -MNG Interstitial delegate
-(void)adsAdapterInterstitialDidLoad:(MNGAdsAdapter *)adsAdapter {
    
    NSLog(@"[MAdvertise]: adsAdapterInterstitialDidLoad");
  
    if ([delegate respondsToSelector:@selector(customEventInterstitialDidReceiveAd:)]) {
        [delegate customEventInterstitialDidReceiveAd:self];
    }
    
}

-(void)adsAdapter:(MNGAdsAdapter *)adsAdapter interstitialDidFailWithError:(NSError *)error {
    NSLog(@"[MAdvertise]: adsAdapterInterstitialDidFailWithError");
    if ([delegate respondsToSelector:@selector(customEventInterstitial:didFailAd:)]) {
        [delegate customEventInterstitial:self didFailAd:error];
    }
    
}
-(void)adsAdapterInterstitialDisappear:(MNGAdsAdapter *)adsAdapter{
    NSLog(@"[MAdvertise]: adsAdapterInterstitialDisappear");

    if ([delegate respondsToSelector:@selector(customEventInterstitialDidDismiss:)]) {
           [delegate customEventInterstitialDidDismiss:self];
       }
}
-(void)adsAdapterAdWasClicked:(MNGAdsAdapter *)adsAdapter{
    NSLog(@"[MAdvertise]: adsAdapterAdWasClicked");

    if ([delegate respondsToSelector:@selector(customEventInterstitialWasClicked:)]) {
        [delegate customEventInterstitialWasClicked:self];
    }
}


-(NSString*)createMngPreferenceKeyWord:(GADCustomEventRequest *)request{
    NSString* keyWord = @"";
    NSString* userRequest = @"";
    NSString*  requestExtrasString = @"";
    if (request.userKeywords.count == 1) {
        userRequest = [request.userKeywords[0] stringByAppendingString:@";"];
    }
    if (request.additionalParameters != nil) {
        requestExtrasString = [NSString stringWithFormat:@"%@", request.additionalParameters];
        requestExtrasString = [requestExtrasString stringByReplacingOccurrencesOfString:@"{"withString:@""];
        requestExtrasString = [requestExtrasString stringByReplacingOccurrencesOfString:@"}"withString:@""];
        requestExtrasString = [requestExtrasString stringByReplacingOccurrencesOfString:@"\n"withString:@""];
        requestExtrasString = [requestExtrasString stringByReplacingOccurrencesOfString:@" "withString:@""];
        NSString *lastChar = [requestExtrasString substringFromIndex:[requestExtrasString length] - 1];
        if ([lastChar isEqualToString:@";"]){
            requestExtrasString = [requestExtrasString substringToIndex:[requestExtrasString length] - 1];
        }
    }
    keyWord = [userRequest stringByAppendingString:requestExtrasString];
    return keyWord;
}

- (NSString * )getAppIdByPlacementFromServerParameter:(NSString  *)serverParameter {
    NSString * appID;
    if (serverParameter != nil) {
        NSArray *items = [serverParameter componentsSeparatedByString:@"/"];
        if (items.count >= 2) {
          appID  =[items objectAtIndex:1];
        }
    }
    return appID;
}

-(void)dealloc{
    if (__interFactory) {
        __interFactory = nil;
    }
}


@end
